@@ -41,7 +41,7 @@ Please refer to the documentation and examples for more information about how wr
 // AddPluginFlags plugins-dir and lookup-plugins to cmd
 func AddPluginFlags(cmd *cobra.Command) {
 	cmd.Flags().StringVar(&commands.Cfg.PluginsDir, "plugins-dir", "~/.kn/plugins", "kn plugins directory")
-	cmd.Flags().BoolVar(&commands.Cfg.LookupPlugins, "lookup-plugins", false, "look for kn plugins in $PATH")
+	cmd.Flags().BoolVar(commands.Cfg.LookupPlugins, "lookup-plugins", false, "look for kn plugins in $PATH")
 }
 
 // BindPluginsFlagToViper bind and set default with viper for plugins flags
