@@ -16,6 +16,8 @@ package revision
 
 import (
 	"github.com/spf13/cobra"
+	"knative.dev/serving/pkg/apis/serving/v1alpha1"
+
 	"knative.dev/client/pkg/kn/commands"
 )
 
@@ -29,3 +31,26 @@ func NewRevisionCommand(p *commands.KnParams) *cobra.Command {
 	revisionCmd.AddCommand(NewRevisionDeleteCommand(p))
 	return revisionCmd
 }
+
+// ============================================
+// Shared revision functions:
+
+// Extract traffic and tags for given revision from a service
+func trafficAndTagsForRevision(revision string, service *v1alpha1.Service) (int64, []string) {
+	if len(service.Status.Traffic) == 0 {
+		return 0, nil
+	}
+	var percent int64
+	var tags []string
+	for _, target := range service.Status.Traffic {
+		if target.RevisionName == revision {
+			if target.Percent != nil {
+				percent += *target.Percent
+			}
+			if target.Tag != "" {
+				tags = append(tags, target.Tag)
+			}
+		}
+	}
+	return percent, tags
+}
