@@ -20,13 +20,14 @@ import (
 
 	"github.com/spf13/cobra"
 	"knative.dev/client/pkg/kn/commands"
+	"knative.dev/client/pkg/kn/commands/flags"
 	v1alpha12 "knative.dev/client/pkg/serving/v1alpha1"
 	"knative.dev/serving/pkg/apis/serving/v1alpha1"
 )
 
 // NewServiceListCommand represents 'kn service list' command
 func NewServiceListCommand(p *commands.KnParams) *cobra.Command {
-	serviceListFlags := NewServiceListFlags()
+	serviceListFlags := flags.NewListPrintFlags(ServiceListHandlers)
 
 	serviceListCommand := &cobra.Command{
 		Use:   "list [name]",
@@ -68,9 +69,15 @@ func NewServiceListCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			// Sort serviceList by name
+			// Sort serviceList by namespace and name (in this order)
 			sort.SliceStable(serviceList.Items, func(i, j int) bool {
-				return serviceList.Items[i].ObjectMeta.Name < serviceList.Items[j].ObjectMeta.Name
+				a := serviceList.Items[i]
+				b := serviceList.Items[j]
+
+				if a.Namespace != b.Namespace {
+					return a.Namespace < b.Namespace
+				}
+				return a.ObjectMeta.Name < b.ObjectMeta.Name
 			})
 
 			err = printer.PrintObj(serviceList, cmd.OutOrStdout())
