@@ -19,6 +19,7 @@ import (
 
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/kn/commands/source/apiserver"
+	"knative.dev/client/pkg/kn/commands/source/binding"
 	"knative.dev/client/pkg/kn/commands/source/cronjob"
 )
 
@@ -30,5 +31,6 @@ func NewSourceCommand(p *commands.KnParams) *cobra.Command {
 	sourceCmd.AddCommand(apiserver.NewAPIServerCommand(p))
 	sourceCmd.AddCommand(NewListTypesCommand(p))
 	sourceCmd.AddCommand(cronjob.NewCronJobCommand(p))
+	sourceCmd.AddCommand(binding.NewBindingCommand(p))
 	return sourceCmd
 }
