@@ -23,13 +23,14 @@ import (
 	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
-	"knative.dev/client/pkg/util"
 	eventing "knative.dev/eventing/pkg/client/clientset/versioned/typed/eventing/v1alpha1"
-	eventing_sources "knative.dev/eventing/pkg/client/clientset/versioned/typed/sources/v1alpha1"
+	eventing_sources "knative.dev/eventing/pkg/legacyclient/clientset/versioned/typed/legacysources/v1alpha1"
 	serving_v1alpha1_client "knative.dev/serving/pkg/client/clientset/versioned/typed/serving/v1alpha1"
 
+	"knative.dev/client/pkg/util"
+
 	dynamic_kn "knative.dev/client/pkg/dynamic"
-	sources_kn_v1alpha1 "knative.dev/client/pkg/eventing/sources/v1alpha1"
+	sources_kn_v1alpha1 "knative.dev/client/pkg/eventing/legacysources/v1alpha1"
 	eventing_kn_v1alpha1 "knative.dev/client/pkg/eventing/v1alpha1"
 	serving_kn_v1alpha1 "knative.dev/client/pkg/serving/v1alpha1"
 )
@@ -38,12 +39,15 @@ import (
 var CfgFile string
 
 // Cfg is Kn's configuration values
-var Cfg Config
+var Cfg Config = Config{
+	PluginsDir:    "",
+	LookupPlugins: newBoolP(false),
+}
 
 // Config contains the variables for the Kn config
 type Config struct {
 	PluginsDir    string
-	LookupPlugins bool
+	LookupPlugins *bool
 }
 
 // KnParams for creating commands. Useful for inserting mocks for testing.
@@ -169,3 +173,11 @@ func (params *KnParams) GetClientConfig() (clientcmd.ClientConfig, error) {
 	}
 	return nil, fmt.Errorf("Config file '%s' can not be found", params.KubeCfgPath)
 }
+
+// Private
+
+// Returns a pointer to bool, hard to do better in Golang
+func newBoolP(b bool) *bool {
+	aBool := b
+	return &aBool
+}
