@@ -21,6 +21,7 @@ import (
 	"sort"
 	"strconv"
 	"strings"
+	"time"
 	"unicode"
 
 	corev1 "k8s.io/api/core/v1"
@@ -183,6 +184,15 @@ func UpdateMaxScale(template *servingv1alpha1.RevisionTemplateSpec, max int) err
 	return UpdateRevisionTemplateAnnotation(template, autoscaling.MaxScaleAnnotationKey, strconv.Itoa(max))
 }
 
+// UpdateAutoscaleWindow updates the autoscale window annotation
+func UpdateAutoscaleWindow(template *servingv1alpha1.RevisionTemplateSpec, window string) error {
+	_, err := time.ParseDuration(window)
+	if err != nil {
+		return fmt.Errorf("invalid duration for 'autoscale-window': %v", err)
+	}
+	return UpdateRevisionTemplateAnnotation(template, autoscaling.WindowAnnotationKey, window)
+}
+
 // UpdateConcurrencyTarget updates container concurrency annotation
 func UpdateConcurrencyTarget(template *servingv1alpha1.RevisionTemplateSpec, target int) error {
 	return UpdateRevisionTemplateAnnotation(template, autoscaling.TargetAnnotationKey, strconv.Itoa(target))
@@ -397,6 +407,18 @@ func UpdateServiceAccountName(template *servingv1alpha1.RevisionTemplateSpec, se
 	return nil
 }
 
+// UpdateImagePullSecrets updates the image pull secrets used for the corresponding knative service
+func UpdateImagePullSecrets(template *servingv1alpha1.RevisionTemplateSpec, pullsecrets string) {
+	pullsecrets = strings.TrimSpace(pullsecrets)
+	if pullsecrets == "" {
+		template.Spec.ImagePullSecrets = nil
+	} else {
+		template.Spec.ImagePullSecrets = []corev1.LocalObjectReference{{
+			Name: pullsecrets,
+		}}
+	}
+}
+
 // GenerateVolumeName generates a volume name with respect to a given path string.
 // Current implementation basically sanitizes the path string by changing "/" into "."
 // To reduce any chance of duplication, a checksum part generated from the path string is appended to the sanitized string.
