@@ -225,7 +225,7 @@ func TestUpdateMinScale(t *testing.T) {
 	err := UpdateMinScale(template, 10)
 	assert.NilError(t, err)
 	// Verify update is successful or not
-	checkAnnotationValue(t, template, autoscaling.MinScaleAnnotationKey, 10)
+	checkAnnotationValueInt(t, template, autoscaling.MinScaleAnnotationKey, 10)
 	// Update with invalid value
 	err = UpdateMinScale(template, -1)
 	assert.ErrorContains(t, err, "minScale")
@@ -236,18 +236,29 @@ func TestUpdateMaxScale(t *testing.T) {
 	err := UpdateMaxScale(template, 10)
 	assert.NilError(t, err)
 	// Verify update is successful or not
-	checkAnnotationValue(t, template, autoscaling.MaxScaleAnnotationKey, 10)
+	checkAnnotationValueInt(t, template, autoscaling.MaxScaleAnnotationKey, 10)
 	// Update with invalid value
 	err = UpdateMaxScale(template, -1)
 	assert.ErrorContains(t, err, "maxScale")
 }
 
+func TestAutoscaleWindow(t *testing.T) {
+	template, _ := getV1alpha1RevisionTemplateWithOldFields()
+	err := UpdateAutoscaleWindow(template, "10s")
+	assert.NilError(t, err)
+	// Verify update is successful or not
+	checkAnnotationValue(t, template, autoscaling.WindowAnnotationKey, "10s")
+	// Update with invalid value
+	err = UpdateAutoscaleWindow(template, "blub")
+	assert.Check(t, util.ContainsAll(err.Error(), "invalid duration", "autoscale-window"))
+}
+
 func TestUpdateConcurrencyTarget(t *testing.T) {
 	template, _ := getV1alpha1RevisionTemplateWithOldFields()
 	err := UpdateConcurrencyTarget(template, 10)
 	assert.NilError(t, err)
 	// Verify update is successful or not
-	checkAnnotationValue(t, template, autoscaling.TargetAnnotationKey, 10)
+	checkAnnotationValueInt(t, template, autoscaling.TargetAnnotationKey, 10)
 	// Update with invalid value
 	err = UpdateConcurrencyTarget(template, -1)
 	assert.ErrorContains(t, err, "invalid")
@@ -551,6 +562,17 @@ func TestUpdateServiceAccountName(t *testing.T) {
 	assert.Equal(t, template.Spec.ServiceAccountName, "")
 }
 
+func TestUpdateImagePullSecrets(t *testing.T) {
+	template, _ := getV1alpha1RevisionTemplateWithOldFields()
+	template.Spec.ImagePullSecrets = nil
+
+	UpdateImagePullSecrets(template, "quay")
+	assert.Equal(t, template.Spec.ImagePullSecrets[0].Name, "quay")
+
+	UpdateImagePullSecrets(template, " ")
+	assert.Check(t, template.Spec.ImagePullSecrets == nil)
+}
+
 func TestUpdateAnnotationsNew(t *testing.T) {
 	service, template, _ := getV1alpha1Service()
 
@@ -708,13 +730,20 @@ func assertNoV1alpha1(t *testing.T, template *servingv1alpha1.RevisionTemplateSp
 	}
 }
 
-func checkAnnotationValue(t *testing.T, template *servingv1alpha1.RevisionTemplateSpec, key string, value int) {
+func checkAnnotationValueInt(t *testing.T, template *servingv1alpha1.RevisionTemplateSpec, key string, value int) {
 	anno := template.GetAnnotations()
 	if v, ok := anno[key]; !ok && v != strconv.Itoa(value) {
 		t.Errorf("Failed to update %s annotation key: got=%s, want=%d", key, v, value)
 	}
 }
 
+func checkAnnotationValue(t *testing.T, template *servingv1alpha1.RevisionTemplateSpec, key string, value string) {
+	anno := template.GetAnnotations()
+	if v, ok := anno[key]; !ok && v != value {
+		t.Errorf("Failed to update %s annotation key: got=%s, want=%s", key, v, value)
+	}
+}
+
 func checkContainerConcurrency(t *testing.T, template *servingv1alpha1.RevisionTemplateSpec, value *int64) {
 	if got, want := *template.Spec.ContainerConcurrency, *value; got != want {
 		t.Errorf("Failed to update containerConcurrency value: got=%d, want=%d", got, want)
