@@ -41,19 +41,22 @@ type runOpts struct {
 const (
 	KnDefaultTestImage string        = "gcr.io/knative-samples/helloworld-go"
 	MaxRetries         int           = 10
-	RetrySleepDuration time.Duration = 30 * time.Second
+	RetrySleepDuration time.Duration = 5 * time.Second
 )
 
 var m sync.Mutex
 
 type e2eTest struct {
-	env env
-	kn  kn
+	env                    env
+	kn                     kn
+	createNamespaceOnSetup bool
+	namespaceCreated       bool
 }
 
 func NewE2eTest(t *testing.T) *e2eTest {
 	return &e2eTest{
-		env: buildEnv(t),
+		env:                    buildEnv(t),
+		createNamespaceOnSetup: true,
 	}
 }
 
@@ -61,8 +64,10 @@ func NewE2eTest(t *testing.T) *e2eTest {
 func (test *e2eTest) Setup(t *testing.T) {
 	test.env.Namespace = fmt.Sprintf("%s%d", test.env.Namespace, getNamespaceCountAndIncrement())
 	test.kn = kn{t, test.env.Namespace, Logger{}}
-	test.CreateTestNamespace(t, test.env.Namespace)
-	time.Sleep(20 * time.Second)
+	if test.createNamespaceOnSetup {
+		test.CreateTestNamespace(t, test.env.Namespace)
+		test.WaitForNamespaceCreated(t, test.env.Namespace)
+	}
 }
 
 func getNamespaceCountAndIncrement() int {
@@ -83,7 +88,9 @@ func getServiceNameAndIncrement(base string) string {
 
 // Teardown clean up
 func (test *e2eTest) Teardown(t *testing.T) {
-	test.DeleteTestNamespace(t, test.env.Namespace)
+	if test.namespaceCreated {
+		test.DeleteTestNamespace(t, test.env.Namespace)
+	}
 }
 
 // CreateTestNamespace creates and tests a namesspace creation invoking kubectl
@@ -92,13 +99,14 @@ func (test *e2eTest) CreateTestNamespace(t *testing.T, namespace string) {
 	expectedOutputRegexp := fmt.Sprintf("namespace?.+%s.+created", namespace)
 	out, err := createNamespace(t, namespace, MaxRetries, logger)
 	if err != nil {
-		logger.Fatalf("Could not create namespace, giving up")
+		logger.Fatalf("Could not create namespace with error %v, giving up\n", err)
 	}
 
 	// check that last output indeed show created namespace
 	if !matchRegexp(t, expectedOutputRegexp, out) {
 		t.Fatalf("Expected output incorrect, expecting to include:\n%s\n Instead found:\n%s\n", expectedOutputRegexp, out)
 	}
+	test.namespaceCreated = true
 }
 
 // CreateTestNamespace deletes and tests a namesspace deletion invoking kubectl
@@ -106,26 +114,36 @@ func (test *e2eTest) DeleteTestNamespace(t *testing.T, namespace string) {
 	kubectl := kubectl{t, Logger{}}
 	out, err := kubectl.RunWithOpts([]string{"delete", "namespace", namespace}, runOpts{})
 	if err != nil {
-		t.Fatalf(fmt.Sprintf("Error executing 'kubectl delete namespace' command. Error: %s", err.Error()))
+		t.Fatalf("Error executing 'kubectl delete namespace' command. Error: %s", err.Error())
 	}
 
 	expectedOutputRegexp := fmt.Sprintf("namespace?.+%s.+deleted", namespace)
 	if !matchRegexp(t, expectedOutputRegexp, out) {
 		t.Fatalf("Expected output incorrect, expecting to include:\n%s\n Instead found:\n%s\n", expectedOutputRegexp, out)
 	}
+	test.namespaceCreated = false
 }
 
 // WaitForNamespaceDeleted wait until namespace is deleted
 func (test *e2eTest) WaitForNamespaceDeleted(t *testing.T, namespace string) {
 	logger := Logger{}
-	deleted := checkNamespaceDeleted(t, namespace, MaxRetries, logger)
+	deleted := checkNamespace(t, namespace, false, MaxRetries, logger)
 	if !deleted {
-		t.Fatalf(fmt.Sprintf("Error deleting namespace %s, timed out", namespace))
+		t.Fatalf("Error deleting namespace %s, timed out", namespace)
+	}
+}
+
+// WaitForNamespaceCreated wait until namespace is created
+func (test *e2eTest) WaitForNamespaceCreated(t *testing.T, namespace string) {
+	logger := Logger{}
+	created := checkNamespace(t, namespace, true, MaxRetries, logger)
+	if !created {
+		t.Fatalf("Error creating namespace %s, timed out", namespace)
 	}
 }
 
 // Private functions
-func checkNamespaceDeleted(t *testing.T, namespace string, maxRetries int, logger Logger) bool {
+func checkNamespace(t *testing.T, namespace string, created bool, maxRetries int, logger Logger) bool {
 	kubectlGetNamespace := func() (string, error) {
 		kubectl := kubectl{t, logger}
 		return kubectl.RunWithOpts([]string{"get", "namespace"}, runOpts{})
@@ -134,7 +152,14 @@ func checkNamespaceDeleted(t *testing.T, namespace string, maxRetries int, logge
 	retries := 0
 	for retries < MaxRetries {
 		output, _ := kubectlGetNamespace()
-		if !strings.Contains(output, namespace) {
+
+		// check for namespace deleted
+		if !created && !strings.Contains(output, namespace) {
+			return true
+		}
+
+		// check for namespace created
+		if created && strings.Contains(output, namespace) {
 			return true
 		}
 
@@ -159,12 +184,12 @@ func createNamespace(t *testing.T, namespace string, maxRetries int, logger Logg
 	)
 
 	for retries < maxRetries {
-		out, err := kubectlCreateNamespace()
+		out, err = kubectlCreateNamespace()
 		if err == nil {
 			return out, nil
 		}
 		retries++
-		logger.Debugf("Could not create namespace, waiting %ds, and trying again: %d of %d\n", int(RetrySleepDuration.Seconds()), retries, maxRetries)
+		logger.Debugf("Could not create namespace with error %v, waiting %ds, and trying again: %d of %d\n", err, int(RetrySleepDuration.Seconds()), retries, maxRetries)
 		time.Sleep(RetrySleepDuration)
 	}
 
@@ -216,7 +241,7 @@ func cmdCLIDesc(cli string, args []string) string {
 func matchRegexp(t *testing.T, matchingRegexp, actual string) bool {
 	matched, err := regexp.MatchString(matchingRegexp, actual)
 	if err != nil {
-		t.Fatalf(fmt.Sprintf("Failed to match regexp '%s'. Error: '%s'", matchingRegexp, err.Error()))
+		t.Fatalf("Failed to match regexp '%s'. Error: '%s'", matchingRegexp, err.Error())
 	}
 	return matched
 }
